namespace dnnl {
namespace impl {
namespace gpu {
namespace intel {
namespace ocl {
const char *combined_reduction_kernel = R"==(/*******************************************************************************)==""\n"
R"==(* Copyright 2021-2024 Intel Corporation)==""\n"
R"==(*)==""\n"
R"==(* Licensed under the Apache License, Version 2.0 (the "License");)==""\n"
R"==(* you may not use this file except in compliance with the License.)==""\n"
R"==(* You may obtain a copy of the License at)==""\n"
R"==(*)==""\n"
R"==(* http:)==""\n"
R"==(*)==""\n"
R"==(* Unless required by applicable law or agreed to in writing, software)==""\n"
R"==(* distributed under the License is distributed on an "AS IS" BASIS,)==""\n"
R"==(* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.)==""\n"
R"==(* See the License for the specific language governing permissions and)==""\n"
R"==(* limitations under the License.)==""\n"
R"==(*******************************************************************************/)==""\n"
R"==(#include "gpu/intel/ocl/ocl_post_ops.h")==""\n"
R"==(#include "gpu/intel/ocl/ocl_types.h")==""\n"
R"==(#include "gpu/intel/ocl/ocl_utils.h")==""\n"
R"==(#include "gpu/intel/ocl/reduction/ocl_reduction.h")==""\n"
R"==(#ifdef OCL_DEBUG)==""\n"
R"==(#define DUMP(str, ...) \)==""\n"
R"==(do { \)==""\n"
R"==(const size_t gid[3] \)==""\n"
R"==(= {get_global_id(0), get_global_id(1), get_global_id(2)}; \)==""\n"
R"==(const size_t lid[3] \)==""\n"
R"==(= {get_local_id(0), get_local_id(1), get_local_id(2)}; \)==""\n"
R"==(const size_t wgid[3] \)==""\n"
R"==(= {get_group_id(0), get_group_id(1), get_group_id(2)}; \)==""\n"
R"==(const size_t lin_g = get_global_linear_id(); \)==""\n"
R"==(const size_t lin_l = get_local_linear_id(); \)==""\n"
R"==(const uint sglid = get_sub_group_local_id(); \)==""\n"
R"==(DEBUG_PRINT( \)==""\n"
R"==("gid=(%zu,%zu,%zu) lid=(%zu,%zu,%zu) " \)==""\n"
R"==("linear=(%zug/%zul/%usg): " str, \)==""\n"
R"==(gid[0], gid[1], gid[2], lid[0], lid[1], lid[2], lin_g, lin_l, \)==""\n"
R"==(sglid, ##__VA_ARGS__) \)==""\n"
R"==(} while (0))==""\n"
R"==(#else)==""\n"
R"==(#define DUMP(...))==""\n"
R"==(#endif)==""\n"
R"==(#define BLOCK_READ_DATA_T(data_ptr) \)==""\n"
R"==(AS_DATA_T(BLOCK_READ((const __global BLOCK_DATA_T *)data_ptr)))==""\n"
R"==(#define READ_DATA(val) WITH_BLOCK_READ ? BLOCK_READ_DATA_T(&val) : val)==""\n"
R"==(#if NUM_SRC_ZPAD > 2 || NUM_DST_ZPAD > 2)==""\n"
R"==(#error "At most 2 zero pad patterns permitted")==""\n"
R"==(#endif)==""\n"
R"==(bool is_dst_zero_padded(const dim_t dst_off) {)==""\n"
R"==(bool ret = false;)==""\n"
R"==(#if NUM_DST_ZPAD >= 1)==""\n"
R"==({)==""\n"
R"==(const dim_t outer_idx = (dst_off / DST_Z0_STRIDE1) % DST_Z0_SIZE1;)==""\n"
R"==(const dim_t inner_idx = (dst_off / DST_Z0_STRIDE0) % DST_Z0_SIZE0;)==""\n"
R"==(ret |= (outer_idx * DST_Z0_SIZE0 + inner_idx >= DST_Z0_SIZE);)==""\n"
R"==(})==""\n"
R"==(#endif)==""\n"
R"==(#if NUM_DST_ZPAD >= 2)==""\n"
R"==({)==""\n"
R"==(const dim_t outer_idx = (dst_off / DST_Z1_STRIDE1) % DST_Z1_SIZE1;)==""\n"
R"==(const dim_t inner_idx = (dst_off / DST_Z1_STRIDE0) % DST_Z1_SIZE0;)==""\n"
R"==(ret |= (outer_idx * DST_Z1_SIZE0 + inner_idx >= DST_Z1_SIZE);)==""\n"
R"==(})==""\n"
R"==(#endif)==""\n"
R"==(return ret;)==""\n"
R"==(})==""\n"
R"==(dim_t dst_off_w_zero_padding(dim_t outer, dim_t inner) {)==""\n"
R"==(dim_t outer_stride = INNER_DIM_SIZE;)==""\n"
R"==(#if NUM_DST_ZPAD >= 1 && DST_Z0_IS_REDUCED)==""\n"
R"==(#if DST_Z0_SIZE1 != 1 || DST_Z0_SIZE != 1)==""\n"
R"==(#error "Reduced zpad #1 doesn't match expected pattern!")==""\n"
R"==(#endif)==""\n"
R"==(outer_stride *= DST_Z0_SIZE0;)==""\n"
R"==(const dim_t inside0 = inner % DST_Z0_STRIDE0;)==""\n"
R"==(const dim_t idx0 = inner / DST_Z0_STRIDE0;)==""\n"
R"==(inner = inside0 + idx0 * DST_Z0_SIZE0 * DST_Z0_STRIDE0;)==""\n"
R"==(#endif)==""\n"
R"==(#if NUM_DST_ZPAD >= 2 && DST_Z1_IS_REDUCED)==""\n"
R"==(#if DST_Z1_SIZE1 != 1 || DST_Z1_SIZE != 1)==""\n"
R"==(#error "Reduced zpad #2 doesn't match expected pattern!")==""\n"
R"==(#endif)==""\n"
R"==(outer_stride *= DST_Z1_SIZE0;)==""\n"
R"==(const dim_t inside1 = inner % DST_Z1_STRIDE0;)==""\n"
R"==(const dim_t idx1 = inner / DST_Z1_STRIDE0;)==""\n"
R"==(inner = inside1 + idx1 * DST_Z1_SIZE0 * DST_Z1_STRIDE0;)==""\n"
R"==(#endif)==""\n"
R"==(return outer * outer_stride + inner;)==""\n"
R"==(})==""\n"
R"==(#define _SRC_OFF(outer, reduction, inner) \)==""\n"
R"==(((outer)*REDUCTION_SIZE * INNER_DIM_SIZE + (reduction)*INNER_DIM_SIZE \)==""\n"
R"==(+ (inner)))==""\n"
R"==(#define _DST_OFF(outer, inner) dst_off_w_zero_padding(outer, inner))==""\n"
R"==(#if NUM_DST_ZPAD == 0)==""\n"
R"==(#define PADDED_NELEMS OUTER_SIZE *INNER_DIM_SIZE)==""\n"
R"==(#elif NUM_DST_ZPAD == 1)==""\n"
R"==(#define PADDED_NELEMS OUTER_SIZE *INNER_DIM_SIZE *DST_Z0_SIZE0 *DST_Z0_SIZE1)==""\n"
R"==(#elif NUM_DST_ZPAD == 2)==""\n"
R"==(#define PADDED_NELEMS \)==""\n"
R"==(OUTER_SIZE *INNER_DIM_SIZE *DST_Z0_SIZE0 *DST_Z0_SIZE1 *DST_Z1_SIZE0 \)==""\n"
R"==(*DST_Z1_SIZE1)==""\n"
R"==(#endif)==""\n"
R"==(#if WITH_POST_OP)==""\n"
R"==(void reverse_indexing(dim_t dst_off, int *res) {)==""\n"
R"==(res[0] = (DST_S0 == 0) ? 0)==""\n"
R"==(: dst_off / DST_S0 % div_up(DST_D0, DST_B0) * DST_B0)==""\n"
R"==(+ dst_off / DST_SB0 % DST_B0;)==""\n"
R"==(res[1] = (DST_S1 == 0) ? 0)==""\n"
R"==(: dst_off / DST_S1 % div_up(DST_D1, DST_B1) * DST_B1)==""\n"
R"==(+ dst_off / DST_SB1 % DST_B1;)==""\n"
R"==(res[2] = (DST_S2 == 0) ? 0)==""\n"
R"==(: dst_off / DST_S2 % div_up(DST_D2, DST_B2) * DST_B2)==""\n"
R"==(+ dst_off / DST_SB2 % DST_B2;)==""\n"
R"==(res[3] = (DST_S3 == 0) ? 0)==""\n"
R"==(: dst_off / DST_S3 % div_up(DST_D3, DST_B3) * DST_B3)==""\n"
R"==(+ dst_off / DST_SB3 % DST_B3;)==""\n"
R"==(res[4] = (DST_S4 == 0) ? 0)==""\n"
R"==(: dst_off / DST_S4 % div_up(DST_D4, DST_B4) * DST_B4)==""\n"
R"==(+ dst_off / DST_SB4 % DST_B4;)==""\n"
R"==(res[5] = (DST_S5 == 0) ? 0)==""\n"
R"==(: dst_off / DST_S5 % div_up(DST_D5, DST_B5) * DST_B5)==""\n"
R"==(+ dst_off / DST_SB5 % DST_B5;)==""\n"
R"==(})==""\n"
R"==(#endif)==""\n"
R"==(__attribute__((overloadable)) void write()==""\n"
R"==(__global DST_DATA_T *dst, DST_DATA_T val) {)==""\n"
R"==(*dst = val;)==""\n"
R"==(})==""\n"
R"==(__attribute__((overloadable)) DST_DATA_T load(__global DST_DATA_T *dst) {)==""\n"
R"==(return *dst;)==""\n"
R"==(})==""\n"
R"==(void write_padded_zeros(__global DST_DATA_T *dst) {)==""\n"
R"==(#if DST_Z0_IS_REDUCED && DST_Z1_IS_REDUCED)==""\n"
R"==(for (int i = 0; i < DST_Z0_SIZE0; i++) {)==""\n"
R"==(for (int j = 0; j < DST_Z1_SIZE0; j++) {)==""\n"
R"==(if (i == 0 && j == 0) continue;)==""\n"
R"==(write(dst + i * DST_Z0_STRIDE0 + j * DST_Z1_STRIDE0, TO_DST(0.0f));)==""\n"
R"==(})==""\n"
R"==(})==""\n"
R"==(#elif DST_Z0_IS_REDUCED)==""\n"
R"==(for (int i = 1; i < DST_Z0_SIZE0; i++) {)==""\n"
R"==(write(dst + i * DST_Z0_STRIDE0, TO_DST(0.0f));)==""\n"
R"==(})==""\n"
R"==(#elif DST_Z1_IS_REDUCED)==""\n"
R"==(for (int j = 1; j < DST_Z1_SIZE0; j++) {)==""\n"
R"==(write(dst + j * DST_Z1_STRIDE0, TO_DST(0.0f));)==""\n"
R"==(})==""\n"
R"==(#endif)==""\n"
R"==(})==""\n"
R"==(#if INNER_DIM_SIZE < SUBGROUP_SIZE)==""\n"
R"==(#define SLM_PER_SG INNER_DIM_SIZE)==""\n"
R"==(#else)==""\n"
R"==(#define SLM_PER_SG SUBGROUP_SIZE)==""\n"
R"==(#endif)==""\n"
R"==(__attribute__((reqd_work_group_size(LWS_SIZE, 1, 1))) )==""\n"
R"==(__attribute__((intel_reqd_sub_group_size(SUBGROUP_SIZE))) )==""\n"
R"==(__kernel void)==""\n"
R"==(combined_reduce()==""\n"
R"==(__global SRC_DATA_T *src, __global DST_DATA_T *dst POST_OP_ARGS) {)==""\n"
R"==(const int sg_per_inner_dim = div_up(INNER_DIM_SIZE, SUBGROUP_SIZE);)==""\n"
R"==(const int red_per_sg)==""\n"
R"==(= min(REDUCTION_SIZE, max(1, SUBGROUP_SIZE / INNER_DIM_SIZE));)==""\n"
R"==(const int wg_reductions = LWS_SIZE / SUBGROUP_SIZE;)==""\n"
R"==(const int other_reductions = red_per_sg * wg_reductions;)==""\n"
R"==(const int num_horiz_reductions = REDUCTION_SIZE / other_reductions;)==""\n"
R"==(const int tail_reductions = REDUCTION_SIZE % other_reductions;)==""\n"
R"==(const int sgid = get_sub_group_id();)==""\n"
R"==(ASSUME(sgid < wg_reductions);)==""\n"
R"==(ASSUME(sgid >= 0);)==""\n"
R"==(const int tgid = get_global_id(0) / LWS_SIZE;)==""\n"
R"==(const int inner_idx_start = (tgid % sg_per_inner_dim) * SUBGROUP_SIZE;)==""\n"
R"==(const int outer_idx_start = tgid / sg_per_inner_dim * OUTER_TILE_SIZE;)==""\n"
R"==(const int sglid = get_sub_group_local_id();)==""\n"
R"==(ASSUME(sglid < SUBGROUP_SIZE);)==""\n"
R"==(ASSUME(sglid >= 0);)==""\n"
R"==(const int inner_idx = (inner_idx_start + sglid) % INNER_DIM_SIZE;)==""\n"
R"==(const int red_off_sg = (inner_idx_start + sglid) / INNER_DIM_SIZE;)==""\n"
R"==(const int red_off_tg = red_off_sg + sgid * red_per_sg;)==""\n"
R"==(const int active_channels = min()==""\n"
R"==(SUBGROUP_SIZE, red_per_sg * (INNER_DIM_SIZE - inner_idx_start));)==""\n"
R"==(ASSUME(active_channels == SUBGROUP_SIZE || !WITH_BLOCK_READ);)==""\n"
R"==(const int loop_stride = _SRC_OFF(0, other_reductions, 0);)==""\n"
R"==(__local DEF_ACC_DATA_T slm_acc[SLM_PER_SG * wg_reductions];)==""\n"
R"==(unroll_for(int oid = 0; oid < OUTER_TILE_SIZE; oid++) {)==""\n"
R"==(const int outer_idx = outer_idx_start + oid;)==""\n"
R"==(DEF_ACC_DATA_T acc;)==""\n"
R"==(init_acc(REDUCTION_ALG, &acc);)==""\n"
R"==(if (sglid < active_channels) {)==""\n"
R"==(int src_off = _SRC_OFF()==""\n"
R"==(outer_idx, red_off_tg - red_off_sg, inner_idx_start);)==""\n"
R"==(if (!WITH_BLOCK_READ) src_off += sglid;)==""\n"
R"==(for (int iters = num_horiz_reductions; iters > 0; --iters) {)==""\n"
R"==(const DATA_T src_val = READ_DATA(src[src_off]);)==""\n"
R"==(acc = reduce()==""\n"
R"==(REDUCTION_ALG, acc, TO_DEF_ACC_DATA_T(src_val), POWER);)==""\n"
R"==(DUMP("(iter +%d) src[%d] = %f\n", iters, src_off,)==""\n"
R"==(CONVERT_FLOAT_T(src_val));)==""\n"
R"==(src_off += loop_stride;)==""\n"
R"==(})==""\n"
R"==(if (red_off_tg < tail_reductions) {)==""\n"
R"==(const DATA_T src_val = READ_DATA(src[src_off]);)==""\n"
R"==(acc = reduce()==""\n"
R"==(REDUCTION_ALG, acc, TO_DEF_ACC_DATA_T(src_val), POWER);)==""\n"
R"==(DUMP("(tail) src[%d] = %f\n", src_off,)==""\n"
R"==(CONVERT_FLOAT_T(src_val));)==""\n"
R"==(})==""\n"
R"==(})==""\n"
R"==(DEF_ACC_DATA_T init;)==""\n"
R"==(init_acc(SECONDARY_REDUCTION_ALG, &init);)==""\n"
R"==(unroll_for(int shift = INNER_DIM_SIZE; shift < active_channels;)==""\n"
R"==(shift *= 2) {)==""\n"
R"==(DEF_ACC_DATA_T next)==""\n"
R"==(= intel_sub_group_shuffle_down(acc, init, shift);)==""\n"
R"==(acc = reduce(SECONDARY_REDUCTION_ALG, acc, next, POWER);)==""\n"
R"==(DUMP("(sg) acc from sglid %d: %f\n", sglid + shift,)==""\n"
R"==(convert_float(next));)==""\n"
R"==(})==""\n"
R"==(if (wg_reductions > 1) {)==""\n"
R"==(const int local_idx = sgid * SLM_PER_SG + sglid;)==""\n"
R"==(if (red_off_sg == 0 && inner_idx < INNER_DIM_SIZE) {)==""\n"
R"==(slm_acc[local_idx] = acc;)==""\n"
R"==(})==""\n"
R"==(init_acc(SECONDARY_REDUCTION_ALG, &acc);)==""\n"
R"==(barrier(CLK_LOCAL_MEM_FENCE);)==""\n"
R"==(if (red_off_tg == 0) {)==""\n"
R"==(unroll_for(int i = 0; i < wg_reductions; i++) {)==""\n"
R"==(const int idx = i * SLM_PER_SG + sglid;)==""\n"
R"==(acc = reduce()==""\n"
R"==(SECONDARY_REDUCTION_ALG, acc, slm_acc[idx], POWER);)==""\n"
R"==(DUMP("(wg) acc from wg %d/%d: %f\n", i, idx,)==""\n"
R"==(convert_float(slm_acc[idx]));)==""\n"
R"==(})==""\n"
R"==(})==""\n"
R"==(})==""\n"
R"==(const dim_t dst_off = _DST_OFF(outer_idx, inner_idx);)==""\n"
R"==(if (red_off_tg == 0) {)==""\n"
R"==(float res = IS_FINAL ? finalize(REDUCTION_ALG, acc, DIV, POWER, EPS))==""\n"
R"==(: acc;)==""\n"
R"==(#if WITH_POST_OP)==""\n"
R"==(float dst_val;)==""\n"
R"==(#if WITH_SUM)==""\n"
R"==(dst_val = DST_TO_REF(load(dst + dst_off));)==""\n"
R"==(#endif )==""\n"
R"==(int idxs[6];)==""\n"
R"==(reverse_indexing(dst_off, idxs);)==""\n"
R"==(if (idxs[0] < DST_D0 && idxs[1] < DST_D1 && idxs[2] < DST_D2)==""\n"
R"==(&& idxs[3] < DST_D3 && idxs[4] < DST_D4)==""\n"
R"==(&& idxs[5] < DST_D5) {)==""\n"
R"==(APPLY_POST_OPS_SERIAL(res, float, dst_val, float, idxs[0], 1,)==""\n"
R"==(idxs[1], 1, idxs[2], 1, idxs[3], 1, idxs[4], 1, idxs[5],)==""\n"
R"==(1);)==""\n"
R"==(})==""\n"
R"==(#endif)==""\n"
R"==(if (is_dst_zero_padded(dst_off)) res = 0.0f;)==""\n"
R"==(write(dst + dst_off, IS_FINAL ? TO_DST(res) : res);)==""\n"
R"==(DUMP("Wrote dst[%ld] = %f\n", dst_off, res);)==""\n"
R"==(write_padded_zeros(dst + dst_off);)==""\n"
R"==(DUMP("dst[%ld] <- %f\n", dst_off, TO_DST(res));)==""\n"
R"==(})==""\n"
R"==(})==""\n"
R"==(})==""\n"
R"==()==";
}
}
}
}
}